# TODO: https://fedoraproject.org/wiki/Packaging:AutoProvidesAndRequiresFiltering
#       rpmlint warns about private-shared-object-provides
#       can't use filter because the package doesn't met any of the required criteria
#         ! Noarch package       ... caused by libreport wrappers shared library
#         ! no binaries in $PATH ... caused by gnome-abrt python script in /usr/bin

Name:       gnome-abrt
Version:    0.2.8
Release:    1%{?dist}
Summary:    A utility for viewing problems that have occurred with the system

Group:      User Interface/Desktops
License:    GPLv2+
URL:        https://fedorahosted.org/abrt/
Source0:    https://fedorahosted.org/released/abrt/%{name}-%{version}.tar.gz

BuildRequires: intltool
BuildRequires: gettext
BuildRequires: libtool
BuildRequires: python2-devel
BuildRequires: desktop-file-utils
BuildRequires: asciidoc
BuildRequires: xmlto
BuildRequires: pygobject3-devel
BuildRequires: libreport-gtk-devel >= 2.0.20
BuildRequires: gtk3-devel

Requires:   python-inotify
Requires:   pygobject3
Requires:   dbus-python

%description
A GNOME application allows users to browse through detected problems and
provides them with convenient way for managing these problems.


%prep
%setup -q


%build
autoconf
%configure
make


%install
make install DESTDIR=$RPM_BUILD_ROOT mandir=%{_mandir}
%find_lang %{name}

# remove all .la and .a files
find $RPM_BUILD_ROOT -name '*.la' -or -name '*.a' | xargs rm -f

desktop-file-install \
    --dir ${RPM_BUILD_ROOT}%{_datadir}/applications \
    --delete-original \
    ${RPM_BUILD_ROOT}%{_datadir}/applications/%{name}.desktop


%post
# update icon cache
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi


%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f %{name}.lang
%doc COPYING
%{python_sitearch}/gnome_abrt
%{_datadir}/%{name}
%{_bindir}/%{name}
%{_datadir}/applications/*
%{_mandir}/man6/%{name}.6*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/*/status/*


%changelog
* Mon Feb 25 2013 Jakub Filak <jfilak@redhat.com> 0.2.8-1
- Try harder when looking for icon and don't cache weak results
- Make controller more robust against invalid arguments
- Check return value of the get selection function
- Require correct version of libreport
- Return an empty list instead of None from OopsWindow.get_selected()
- Return an empty list instead of None from get_problems() in case of DBus error
- Get rid of unnecessary variable from the directory source
- Add a cmd line argument for selected problem id
- Resolves: #911711, #912877

* Mon Jan 08 2013 Jakub Filak <jfilak@redhat.com> - 0.2.6-1
- Require libreport version 2.0.20 and greater
- Use DD api correctly
- Reflect changes in libreport
- Resolves: #890357

* Wed Nov 28 2012 Jakub Filak <jfilak@redhat.com> - 0.2.5-1
- Add licenses to all files
- Refresh view's source if InvalidProblem exception is caught during GUI update
- Properly handle removal of the first and the last problem from the list
- Use right tree model in searching for problems
- Use theme backround color as background for the link buttons
- Make the links to servers less moving
- Keep user's selection even if a source has changed
- Destroy abrt-handle-event zombies
- Resolves: rhbz#878035

* Mon Nov 12 2012 Jakub Filak <jfilak@redhat.com> - 0.2.4-1
- Fix label fields size
- Assure ownership of reported problem
- Remove unnecessary GtkEventBox
- Fix appearance of link button widget to no longer have a white background
- Update translations

* Fri Oct 05 2012 Jakub Filak <jfilak@redhat.com> - 0.2.3-1
- Generate version
- Add GNOME3 application menu
- Use correct D-Bus path to listen on for Crash signal
- Make path to abrt-handle-event configurable
- Fix a bug in running of subprocesses
- Refactorize directory problems implementation
- Don't print weired debug message
- Don't show the 'reconnecting to dbus' warning
- Don't show new root's crashes by default
- Fix indentation

* Fri Sep 21 2012 Jakub Filak <jfilak@redhat.com> - 0.2.2-1
- Lazy initialization of directory source
- Don't utilize CPU for 99%
- Code refactorization
- Add translation from the ABRT project
- Properly log exceptions
- Delete directory problems marked as invalid after refresh in inotify handler
- Declare directory problems deleted if its directory doesn't exist
- Fix indentation bug in icon look up algorithm
- Add --verbose command line argument
- Add directory name to error messages

* Mon Sep 17 2012 Jakub Filak <jfilak@redhat.com> - 0.2.1-4
- Fix a problem with desktop items without icons
- A bit better handling of uncaght exceptions

* Mon Sep 17 2012 Jakub Filak <jfilak@redhat.com> - 0.2.1-3
- Add cs and et translations

* Fri Sep 14 2012 Jakub Filak <jfilak@redhat.com> - 0.2.1-2
- Fixed problem with selection of problem after start up
- Corrected application icon look up algorithm
- Fixed problem with missing problems directory

* Fri Sep 14 2012 Jakub Filak <jfilak@redhat.com> - 0.2.1-1
- Detail button replaced by list of reported_to links
- Improved look (margins, icons, wider window by default)
- Implemented multiple delete
- Changed window tiple
- Double click and keyboard shortcuts

* Thu Sep 06 2012 Jakub Filak <jfilak@redhat.com> - 0.2-9
- Remove noarch because of binary wrappers
- Added support for adjusting libreport preferences

* Mon Aug 28 2012 Jakub Filak <jfilak@redhat.com> - 0.2-8
- Take ownership of all installed directories
- Correct paths to translated files

* Mon Aug 27 2012 Jakub Filak <jfilak@redhat.com> - 0.2-7
- Dropped versions from requires
- Simplified spec
- Removed pylint check from configure.ac
- Whitespace cleanup (rmarko@redhat.com)

* Fri Aug 24 2012 Jakub Filak <jfilak@redhat.com> - 0.2-6
- Use own icons set

* Fri Aug 24 2012 Jakub Filak <jfilak@redhat.com> - 0.2-5
- Reorganize source files
- Get rid of all rpmlint complaints

* Thu Aug 23 2012 Jakub Filak <jfilak@redhat.com> - 0.2-4
- Update GUI on various signals (new problem, problem changed, etc.)
- Sort problems by time in descending order
- Correct internationalization in date string generator

* Wed Aug 15 2012 Jakub Filak <jfilak@redhat.com> - 0.2-3
- Reconnect to DBus bus
- Default values for missing items
- Correct field for 'is_reported' flag

* Wed Aug 15 2012 Jakub Filak <jfilak@redhat.com> - 0.2-2
- Add missing files

* Wed Aug 15 2012 Jakub Filak <jfilak@redhat.com> - 0.2-1
- Problems filtering
- Errors handling
- Localization support

* Mon Aug 13 2012 Jakub Filak <jfilak@redhat.com> - 0.1-1
- Initial version
